@@ -32,20 +32,35 @@ namespace Akonadi {
 class AKONADI_CALENDAR_EXPORT PublishDialog : public KDialog
 {
   Q_OBJECT
-  public:
-    explicit PublishDialog( QWidget *parent=0 );
-    ~PublishDialog();
+public:
+  /**
+   * Creates a new PublishDialog
+   * @param parent the dialog's parent
+   */
+  explicit PublishDialog( QWidget *parent=0 );
 
-    void addAttendee( const KCalCore::Attendee::Ptr &attendee );
-    QString addresses() const;
+  /**
+   * Destructor
+   */
+  ~PublishDialog();
 
-  Q_SIGNALS:
-    void numMessagesChanged( int );
-  private:
-    //@cond PRIVATE
-    class Private;
-    Private *const d;
-    //@endcond
+  /**
+   * Adds a new attendee to the dialog
+   * @param attendee the attendee to add
+   */
+  void addAttendee( const KCalCore::Attendee::Ptr &attendee );
+
+  /**
+   * Returns a list of... TODO: this actually returns full names, not addresses.
+   *                      TODO: Also, why not return QStringList.
+   */
+  QString addresses() const;
+
+private:
+  //@cond PRIVATE
+  class Private;
+  Private *const d;
+  //@endcond
 };
 
 }
