@@ -28,7 +28,7 @@
 #include <kdebug.h>
 #include <ktabwidget.h>
 
-#include <QtGui/QBoxLayout>
+#include <QBoxLayout>
 
 using namespace Akonadi;
 
@@ -64,6 +64,17 @@ class CollectionPropertiesDialog::Private
       q->deleteLater();
     }
 
+    void setCurrentPage( const QString &name )
+    {
+      for ( int i = 0; i < mTabWidget->count(); ++i ) {
+        QWidget *w = mTabWidget->widget( i );
+        if ( w->objectName() == name ) {
+          mTabWidget->setCurrentIndex( i );
+          break;
+        }
+      }
+    }
+
     CollectionPropertiesDialog *q;
     Collection mCollection;
     QStringList mPageNames;
@@ -81,16 +92,18 @@ CollectionPropertiesDialog::Private::Private( CollectionPropertiesDialog *qq, co
     mCollection( collection ),
     mPageNames( pageNames )
 {
-  if ( s_defaultPage )
+  if ( s_defaultPage ) {
     registerBuiltinPages();
+  }
 }
 
 void CollectionPropertiesDialog::Private::registerBuiltinPages()
 {
   static bool registered = false;
 
-  if ( registered )
+  if ( registered ) {
     return;
+  }
 
   s_pages->append( new CollectionGeneralPropertiesPageFactory() );
   s_pages->append( new CachePolicyPageFactory() );
@@ -164,8 +177,9 @@ CollectionPropertiesDialog::~CollectionPropertiesDialog()
 
 void CollectionPropertiesDialog::registerPage( CollectionPropertiesPageFactory *factory )
 {
-  if ( s_pages->isEmpty() && s_defaultPage )
+  if ( s_pages->isEmpty() && s_defaultPage ) {
     Private::registerBuiltinPages();
+  }
   s_pages->append( factory );
 }
 
@@ -186,4 +200,9 @@ QString CollectionPropertiesDialog::defaultPageObjectName( DefaultPage page )
   return QString();
 }
 
-#include "collectionpropertiesdialog.moc"
+void CollectionPropertiesDialog::setCurrentPage( const QString &name )
+{
+  d->setCurrentPage( name );
+}
+
+#include "moc_collectionpropertiesdialog.cpp"
