@@ -187,11 +187,11 @@ KABC::ContactGroup::List ContactGroupSearchJob::contactGroups() const
   KABC::ContactGroup::List contactGroups;
 
   foreach ( const Item &item, items() ) {
-    if ( item.hasPayload<KABC::ContactGroup>() )
+    if ( item.hasPayload<KABC::ContactGroup>() ) {
       contactGroups.append( item.payload<KABC::ContactGroup>() );
+    }
   }
 
   return contactGroups;
 }
 
-#include "contactgroupsearchjob.moc"
