@@ -49,7 +49,6 @@ ContactSearchJob::ContactSearchJob( QObject * parent )
                                           "  </query>"
                                           "</request>"
 #else
-                                          "prefix nco:<http://www.semanticdesktop.org/ontologies/2007/03/22/nco#>"
                                           "SELECT ?r WHERE { ?r a nco:Contact }"
 #endif
                                         ) );
@@ -69,17 +68,19 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value )
 // string either as a whole word, the start of a word, or anywhere in a word
 static QString containsQueryString( bool doWholeWordSearch, bool matchWordBoundary )
 {
-  if ( doWholeWordSearch )
+  if ( doWholeWordSearch ) {
     return QString::fromLatin1( "?v bif:contains \"'%1'\" . " );
-  else
-    return QString::fromLatin1("FILTER regex(str(?v), \"%1\", \"i\")" )
-        .arg( matchWordBoundary? QLatin1String("\\\\b%1") : QLatin1String("%1") );
+  } else {
+    return QString::fromLatin1( "FILTER regex(str(?v), \"%1\", \"i\")" )
+        .arg( matchWordBoundary? QLatin1String( "\\\\b%1" ) : QLatin1String( "%1" ) );
+  }
 }
 
 void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Match match )
 {
-  if ( match == StartsWithMatch && value.size() < 4 )
+  if ( match == StartsWithMatch && value.size() < 4 ) {
     match = ExactMatch;
+  }
 
   const bool doWholeWordSearch = value.size() < 3;
   const bool matchWordBoundary = match == ContainsWordBoundaryMatch;
@@ -113,7 +114,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:fullname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. "
           "  "
           "} "
@@ -141,8 +141,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:Contact ; "
-          "            nco:hasEmailAddress ?email . "
+          "    ?person nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> . "
           "   "
           "}"
@@ -170,7 +169,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:nickname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> ."
           "  "
           "}"
@@ -212,12 +210,8 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
-          "    { ?r nco:fullname \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. } "
-          "    UNION "
-          "    { ?r nco:nameGiven \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. } "
-          "    UNION "
-          "    { ?r nco:nameFamily \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. } "
+          "    { ?r ?p \"%1\"^^<http://www.w3.org/2001/XMLSchema#string>. "
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily)) . }"
           "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> . } "
@@ -247,7 +241,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:contactUID \"%1\"^^<http://www.w3.org/2001/XMLSchema#string> ."
           "   "
           "}"
@@ -277,7 +270,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:fullname ?v . "
           "    ?v bif:contains \"'%1*'\" . "
           "  "
@@ -306,10 +298,9 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:Contact ; "
-          "            nco:hasEmailAddress ?email . "
+          "    ?person nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress ?v . "
-          "    FILTER regex(str(?v), \"^%1\", \"i\") "
+          "    ?v bif:contains \"'%1\'\" . "
           "  "
           "}"
 #endif
@@ -336,9 +327,8 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:nickname ?v . "
-          "    FILTER regex(str(?v), \"^%1\", \"i\") "
+          "    ?v bif:contains \"'%1\'\" . "
           "  "
           "}"
 #endif
@@ -379,19 +369,13 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "   "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
-          "    { ?r nco:fullname ?v . "
-          "      FILTER regex(str(?v), \"^%1\", \"i\") } "
-          "    UNION "
-          "    { ?r nco:nameGiven ?v . "
-          "      FILTER regex(str(?v), \"^%1\", \"i\") } "
-          "    UNION "
-          "    { ?r nco:nameFamily ?v . "
-          "      FILTER regex(str(?v), \"^%1\", \"i\") } "
+          "    { ?r ?p ?v . "
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily)). "
+          "      ?v bif:contains \"'%1'\" . }"
           "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress ?v . "
-          "      FILTER regex(str(?v), \"^%1\", \"i\") } "
+          "      ?v bif:contains \"'%1'\" . }"
           "  "
           "}"
 #endif
@@ -418,14 +402,13 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:contactUID ?v . "
           "    ?v bif:contains \"'%1*'\" . "
           " "
           "}"
 #endif
       );
-    } 
+    }
   } else if ( match == ContainsMatch || match == ContainsWordBoundaryMatch ) {
     if ( criterion == Name ) {
       query += QString::fromLatin1(
@@ -449,7 +432,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:fullname ?v . "
           "%1"
           "  "
@@ -479,8 +461,7 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "  "
           "    ?person <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?person a nco:Contact ; "
-          "            nco:hasEmailAddress ?email . "
+          "    ?person nco:hasEmailAddress ?email . "
           "    ?email nco:emailAddress ?v . "
           "%1"
           "  "
@@ -510,7 +491,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:nickname ?v . "
           "%1"
           "  "
@@ -553,17 +533,10 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "SELECT DISTINCT ?r ?reqProp1 "
           "WHERE { "
           "  "
-          "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
-          "    { ?r nco:fullname ?v . "
+          "    ?r<" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
+          "    { ?r ?p ?v ."
+          "      FILTER(?p in (nco:fullname, nco:nameGiven, nco:nameFamily) ) ."
           "%1 }"
-          "    UNION "
-          "    { ?r nco:nameGiven ?v . "
-          "%1 }"
-          "    UNION "
-          "    { ?r nco:nameFamily ?v . "
-          "%1 }"
-          "    UNION "
           "    { ?r nco:hasEmailAddress ?email . "
           "      ?email nco:emailAddress ?v . "
           "%1 }"
@@ -594,7 +567,6 @@ void ContactSearchJob::setQuery( Criterion criterion, const QString &value, Matc
           "WHERE { "
           "  "
           "    ?r <" + akonadiItemIdUri().toEncoded() + "> ?reqProp1 . "
-          "    ?r a nco:Contact . "
           "    ?r nco:contactUID ?v . "
           "    ?v bif:contains \"'%1'\" . "
           " "
@@ -624,11 +596,11 @@ KABC::Addressee::List ContactSearchJob::contacts() const
   KABC::Addressee::List contacts;
 
   foreach ( const Item &item, items() ) {
-    if ( item.hasPayload<KABC::Addressee>() )
+    if ( item.hasPayload<KABC::Addressee>() ) {
       contacts.append( item.payload<KABC::Addressee>() );
+    }
   }
 
   return contacts;
 }
 
-#include "contactsearchjob.moc"
