@@ -19,6 +19,7 @@
 
 #include "firstrun_p.h"
 #include "dbusconnectionpool.h"
+#include "servermanager.h"
 
 #include <akonadi/agentinstance.h>
 #include <akonadi/agentinstancecreatejob.h>
@@ -45,10 +46,16 @@ using namespace Akonadi;
 
 Firstrun::Firstrun( QObject *parent )
   : QObject( parent ),
-    mConfig( new KConfig( QLatin1String( "akonadi-firstrunrc" ) ) ),
+    mConfig( new KConfig( ServerManager::addNamespace( QLatin1String( "akonadi-firstrunrc" ) ) ) ),
     mCurrentDefault( 0 ),
     mProcess( 0 )
 {
+  //The code in firstrun is not safe in multi-instance mode
+  Q_ASSERT( !ServerManager::hasInstanceIdentifier() );
+  if ( !ServerManager::hasInstanceIdentifier() ) {
+    deleteLater();
+    return;
+  }
   kDebug();
   if ( DBusConnectionPool::threadConnection().registerService( QLatin1String( FIRSTRUN_DBUSLOCK ) ) ) {
     findPendingDefaults();
@@ -80,25 +87,28 @@ void Firstrun::findPendingDefaults()
         kWarning() << "Found invalid default configuration in " << fullName;
         continue;
       }
-      if ( cfg.hasKey( id ) )
+      if ( cfg.hasKey( id ) ) {
         continue;
+      }
       mPendingDefaults << dirName + fileName;
     }
   }
 
 #ifndef KDEPIM_NO_KRESOURCES
   // always check legacy kres for migration, their migrator might have changed again
-  mPendingKres << QLatin1String("contact") << QLatin1String("calendar");
+  mPendingKres << QLatin1String( "contact" ) << QLatin1String( "calendar" );
 #endif
 }
 
 #ifndef KDEPIM_NO_KRESOURCES
 static QString resourceTypeForMimetype( const QStringList &mimeTypes )
 {
-  if ( mimeTypes.contains( QLatin1String( "text/directory" ) ) )
+  if ( mimeTypes.contains( QLatin1String( "text/directory" ) ) ) {
     return QString::fromLatin1( "contact" );
-  if ( mimeTypes.contains( QLatin1String( "text/calendar" ) ) )
+  }
+  if ( mimeTypes.contains( QLatin1String( "text/calendar" ) ) ) {
     return QString::fromLatin1( "calendar" );
+  }
   // TODO notes
   return QString();
 }
@@ -298,4 +308,4 @@ QVariant::Type Firstrun::argumentType( const QMetaObject *mo, const QString &met
   return QVariant::nameToType( argTypes.first() );
 }
 
-#include "firstrun_p.moc"
+#include "moc_firstrun_p.cpp"
