@@ -26,8 +26,8 @@
 #include "emptytrashcommand_p.h"
 #include "markascommand_p.h"
 #include "movetotrashcommand_p.h"
-#include "removeduplicatescommand_p.h"
 #include "specialmailcollections.h"
+#include "removeduplicatesjob.h"
 
 #include "akonadi/agentfilterproxymodel.h"
 #include "akonadi/agentinstance.h"
@@ -37,6 +37,7 @@
 #include "akonadi/collectionstatistics.h"
 #include "akonadi/entitytreemodel.h"
 #include "akonadi/kmime/messagestatus.h"
+#include "util_p.h"
 #include "akonadi/mimetypechecker.h"
 #include "akonadi/subscriptiondialog_p.h"
 
@@ -47,7 +48,7 @@
 #include <kmime/kmime_message.h>
 
 #include <QtCore/QPointer>
-#include <QtGui/QItemSelectionModel>
+#include <QItemSelectionModel>
 
 using namespace Akonadi;
 
@@ -311,65 +312,75 @@ class StandardMailActionManager::Private
         foreach ( const Akonadi::Item &item, selectedItems ) {
           Akonadi::MessageStatus status;
           status.setStatusFromFlags( item.flags() );
-          if ( !status.isImportant() )
+          if ( !status.isImportant() ) {
             allMarkedAsImportant = false;
-          if ( !status.isRead() )
+          }
+          if ( !status.isRead() ) {
             allMarkedAsRead= false;
-	  else 
+          } else {
 	    allMarkedAsUnread = false;
-          if ( !status.isToAct() )
+          }
+          if ( !status.isToAct() ) {
             allMarkedAsActionItem = false;
+          }
         }
 
         QAction *action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsRead );
         if ( action ) {
           updateMarkAction( action, allMarkedAsRead );
-          if ( allMarkedAsRead )
-            action->setEnabled(false);
-          else
+          if ( allMarkedAsRead ) {
+            action->setEnabled( false );
+          } else {
             action->setEnabled( true );
+          }
         }
 
         action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsUnread );
         if ( action ) {
           updateMarkAction( action, allMarkedAsUnread );
-          if ( allMarkedAsUnread )
-            action->setEnabled(false);
-          else
+          if ( allMarkedAsUnread ) {
+            action->setEnabled( false );
+          } else {
             action->setEnabled( true );
+          }
         }
 
         action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsImportant );
         if ( action ) {
           updateMarkAction( action, allMarkedAsImportant );
-          if ( allMarkedAsImportant )
+          if ( allMarkedAsImportant ) {
             action->setText( i18n( "Remove Important Mark" ) );
-          else
+          } else {
             action->setText( i18n( "&Mark Mail as Important" ) );
+          }
           action->setEnabled( true );
         }
 
         action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsActionItem );
         if ( action ) {
           updateMarkAction( action, allMarkedAsActionItem );
-          if ( allMarkedAsActionItem )
+          if ( allMarkedAsActionItem ) {
             action->setText( i18n( "Remove Action Item Mark" ) );
-          else
+          } else {
             action->setText( i18n( "&Mark Mail as Action Item" ) );
+          }
           action->setEnabled( true );
         }
      } else {
         QAction *action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsRead );
-        if ( action )
+        if ( action ) {
           action->setEnabled( false );
+        }
 
         action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsImportant );
-        if ( action )
+        if ( action ) {
           action->setEnabled( false );
+        }
 
         action = mActions.value( Akonadi::StandardMailActionManager::MarkMailAsActionItem );
-        if ( action )
+        if ( action ) {
           action->setEnabled( false );
+        }
      }
 
       bool enableMarkAllAsRead = false;
@@ -377,27 +388,30 @@ class StandardMailActionManager::Private
       bool canDeleteItem = true;
       bool isSystemFolder = false;
       if ( collectionIsSelected ) {
-        foreach( const Collection &collection, selectedCollections )
-        {
+        foreach ( const Collection &collection, selectedCollections ) {
           if ( collection.isValid() ) {
             const Akonadi::CollectionStatistics stats = collection.statistics();
-            if ( !enableMarkAllAsRead )
-              enableMarkAllAsRead = (stats.unreadCount() > 0);
-            if ( !enableMarkAllAsUnread )
-              enableMarkAllAsUnread = (stats.count() != stats.unreadCount());
-            if ( canDeleteItem )
+            if ( !enableMarkAllAsRead ) {
+              enableMarkAllAsRead = ( stats.unreadCount() > 0 );
+            }
+            if ( !enableMarkAllAsUnread ) {
+              enableMarkAllAsUnread = ( stats.count() != stats.unreadCount() );
+            }
+            if ( canDeleteItem ) {
               canDeleteItem = collection.rights() & Akonadi::Collection::CanDeleteItem;
+            }
             if ( !isSystemFolder ) {
-              isSystemFolder = (collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Inbox ) ||
-                                collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Outbox ) ||
-                                collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::SentMail ) ||
-                                collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Trash ) ||
-                                collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Drafts ) ||
-                                collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Templates ));
+              isSystemFolder = ( collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Inbox ) ||
+                                 collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Outbox ) ||
+                                 collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::SentMail ) ||
+                                 collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Trash ) ||
+                                 collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Drafts ) ||
+                                 collection == SpecialMailCollections::self()->defaultCollection( SpecialMailCollections::Templates ) );
             }
             //We will not change after that.
-            if ( enableMarkAllAsRead && enableMarkAllAsUnread && !canDeleteItem && isSystemFolder )
+            if ( enableMarkAllAsRead && enableMarkAllAsUnread && !canDeleteItem && isSystemFolder ) {
               break;
+            }
           }
         }
       }
@@ -407,10 +421,12 @@ class StandardMailActionManager::Private
         }
       }
 
-      if ( mActions.contains( Akonadi::StandardMailActionManager::MoveToTrash ) )
+      if ( mActions.contains( Akonadi::StandardMailActionManager::MoveToTrash ) ) {
         mActions.value( Akonadi::StandardMailActionManager::MoveToTrash )->setEnabled( itemIsSelected && canDeleteItem );
-      if ( mActions.contains( Akonadi::StandardMailActionManager::RemoveDuplicates ) )
+      }
+      if ( mActions.contains( Akonadi::StandardMailActionManager::RemoveDuplicates ) ) {
         mActions.value( Akonadi::StandardMailActionManager::RemoveDuplicates )->setEnabled( canDeleteItem );
+      }
 
       QAction *action = mActions.value( Akonadi::StandardMailActionManager::MarkAllMailAsRead );
       if ( action ) {
@@ -429,11 +445,13 @@ class StandardMailActionManager::Private
     {
       QByteArray data = action->data().toByteArray();
       if ( allMarked ) {
-        if ( !data.startsWith( '!' ) )
+        if ( !data.startsWith( '!' ) ) {
           data.prepend( '!' );
+        }
       } else {
-        if ( data.startsWith( '!' ) )
+        if ( data.startsWith( '!' ) ) {
           data = data.mid( 1 );
+        }
       }
       action->setData( data );
     }
@@ -444,8 +462,9 @@ class StandardMailActionManager::Private
       Q_ASSERT( action );
 
       const Akonadi::Item::List items = mGenericManager->selectedItems();
-      if ( items.isEmpty() )
+      if ( items.isEmpty() ) {
         return;
+      }
 
       QByteArray typeStr = action->data().toByteArray();
       kDebug() << "Mark mail as: " << typeStr;
@@ -464,13 +483,15 @@ class StandardMailActionManager::Private
         type = MarkMailAsUnread;
         targetStatus.setRead( true );
         invert = true;
-      } else if ( typeStr == "K" )
+      } else if ( typeStr == "K" ) {
         type = MarkMailAsActionItem;
-      else if ( typeStr == "G" )
+      } else if ( typeStr == "G" ) {
         type = MarkMailAsImportant;
+      }
 
-      if ( mInterceptedActions.contains( type ) )
+      if ( mInterceptedActions.contains( type ) ) {
         return;
+      }
 
       MarkAsCommand *command = new MarkAsCommand( targetStatus, items, invert, mParent );
       command->execute();
@@ -485,8 +506,9 @@ class StandardMailActionManager::Private
       kDebug() << "Mark all as: " << typeStr;
 
       const Akonadi::Collection::List collections = mGenericManager->selectedCollections();
-      if ( collections.isEmpty() )
+      if ( collections.isEmpty() ) {
         return;
+      }
 
       Akonadi::MessageStatus targetStatus;
       targetStatus.setStatusFromStr( QLatin1String( typeStr ) );
@@ -502,13 +524,15 @@ class StandardMailActionManager::Private
         type = MarkAllMailAsUnread;
         targetStatus.setRead( true );
         invert = true;
-      } else if ( typeStr == "K" )
+      } else if ( typeStr == "K" ) {
         type = MarkAllMailAsActionItem;
-      else if ( typeStr == "G" )
+      } else if ( typeStr == "G" ) {
         type = MarkAllMailAsImportant;
+      }
 
-      if ( mInterceptedActions.contains( type ) )
+      if ( mInterceptedActions.contains( type ) ) {
         return;
+      }
 
       MarkAsCommand *command = new MarkAsCommand( targetStatus, collections, invert, mParent );
       command->execute();
@@ -516,15 +540,18 @@ class StandardMailActionManager::Private
 
     void slotMoveToTrash()
     {
-      if ( mInterceptedActions.contains( StandardMailActionManager::MoveToTrash ) )
+      if ( mInterceptedActions.contains( StandardMailActionManager::MoveToTrash ) ) {
         return;
+      }
 
-      if ( mCollectionSelectionModel->selection().indexes().isEmpty() )
+      if ( mCollectionSelectionModel->selection().indexes().isEmpty() ) {
         return;
+      }
 
       const Item::List items = mGenericManager->selectedItems();
-      if ( items.isEmpty() )
+      if ( items.isEmpty() ) {
         return;
+      }
 
       MoveToTrashCommand *command = new MoveToTrashCommand( mCollectionSelectionModel->model(), items, mParent );
       command->execute();
@@ -532,15 +559,18 @@ class StandardMailActionManager::Private
 
     void slotMoveAllToTrash()
     {
-      if ( mInterceptedActions.contains( StandardMailActionManager::MoveAllToTrash ) )
+      if ( mInterceptedActions.contains( StandardMailActionManager::MoveAllToTrash ) ) {
         return;
+      }
 
-      if ( mCollectionSelectionModel->selection().indexes().isEmpty() )
+      if ( mCollectionSelectionModel->selection().indexes().isEmpty() ) {
         return;
+      }
 
       const Collection::List collections = mGenericManager->selectedCollections();
-      if ( collections.isEmpty() )
+      if ( collections.isEmpty() ) {
         return;
+      }
 
       MoveToTrashCommand *command = new MoveToTrashCommand( mCollectionSelectionModel->model(), collections, mParent );
       command->execute();
@@ -548,21 +578,31 @@ class StandardMailActionManager::Private
 
     void slotRemoveDuplicates()
     {
-      if ( mInterceptedActions.contains( StandardMailActionManager::RemoveDuplicates ) )
+      if ( mInterceptedActions.contains( StandardMailActionManager::RemoveDuplicates ) ) {
         return;
+      }
 
       const Collection::List collections = mGenericManager->selectedCollections();
-      if ( collections.isEmpty() )
+      if ( collections.isEmpty() ) {
         return;
+      }
 
-      RemoveDuplicatesCommand *command = new RemoveDuplicatesCommand( mCollectionSelectionModel->model(), collections, mParent );
-      command->execute();
+      RemoveDuplicatesJob *job = new RemoveDuplicatesJob( collections, mParent );
+      connect( job, SIGNAL(finished(KJob*)), mParent, SLOT(slotJobFinished(KJob*)) );
+    }
+
+    void slotJobFinished( KJob *job )
+    {
+      if ( job->error() ) {
+        Util::showJobError( job );
+      }
     }
 
     void slotEmptyAllTrash()
     {
-      if ( mInterceptedActions.contains( StandardMailActionManager::EmptyAllTrash ) )
+      if ( mInterceptedActions.contains( StandardMailActionManager::EmptyAllTrash ) ) {
         return;
+      }
 
       EmptyTrashCommand *command = new EmptyTrashCommand( const_cast<QAbstractItemModel*>( mCollectionSelectionModel->model() ), mParent );
       command->execute();
@@ -570,15 +610,18 @@ class StandardMailActionManager::Private
 
     void slotEmptyTrash()
     {
-      if ( mInterceptedActions.contains( StandardMailActionManager::EmptyTrash ) )
+      if ( mInterceptedActions.contains( StandardMailActionManager::EmptyTrash ) ) {
         return;
+      }
 
-      if ( mCollectionSelectionModel->selection().indexes().isEmpty() )
+      if ( mCollectionSelectionModel->selection().indexes().isEmpty() ) {
         return;
+      }
 
       const Collection::List collections = mGenericManager->selectedCollections();
-      if ( collections.count() != 1 )
+      if ( collections.count() != 1 ) {
         return;
+      }
 
       EmptyTrashCommand *command = new EmptyTrashCommand( collections.first(), mParent );
       command->execute();
@@ -637,8 +680,9 @@ void StandardMailActionManager::setItemSelectionModel( QItemSelectionModel* sele
 
 KAction* StandardMailActionManager::createAction( Type type )
 {
-  if ( d->mActions.contains( type ) )
+  if ( d->mActions.contains( type ) ) {
     return d->mActions.value( type );
+  }
 
   KAction *action = 0;
 
@@ -722,7 +766,7 @@ KAction* StandardMailActionManager::createAction( Type type )
       action->setIcon( KIcon( QLatin1String( "mail-mark-task" ) ) );
       d->mActions.insert( MarkAllMailAsActionItem, action );
       d->mActionCollection->addAction( QString::fromLatin1( "akonadi_mark_all_as_action_item" ), action );
-      action->setData( QByteArray("K") );
+      action->setData( QByteArray( "K" ) );
       connect( action, SIGNAL(triggered(bool)), this, SLOT(slotMarkAllAs()) );
       break;
     case MoveToTrash:
@@ -806,8 +850,9 @@ void StandardMailActionManager::createAllActions()
 
 KAction* StandardMailActionManager::action( Type type ) const
 {
-  if ( d->mActions.contains( type ) )
+  if ( d->mActions.contains( type ) ) {
     return d->mActions.value( type );
+  }
 
   return 0;
 }
@@ -824,10 +869,11 @@ void StandardMailActionManager::setActionText( StandardActionManager::Type type,
 
 void StandardMailActionManager::interceptAction( Type type, bool intercept )
 {
-  if ( intercept )
+  if ( intercept ) {
     d->mInterceptedActions.insert( type );
-  else
+  } else {
     d->mInterceptedActions.remove( type );
+  }
 }
 
 void StandardMailActionManager::interceptAction( StandardActionManager::Type type, bool intercept )
@@ -865,5 +911,4 @@ Akonadi::StandardActionManager* StandardMailActionManager::standardActionManager
   return d->mGenericManager;
 }
 
-
-#include "standardmailactionmanager.moc"
+#include "moc_standardmailactionmanager.cpp"
