@@ -27,12 +27,16 @@ class ResourceSchedulerTest : public QObject
   Q_OBJECT
   public Q_SLOTS:
     void customTask( const QVariant &argument );
+    void customTaskNoArg();
 
   private Q_SLOTS:
 
     void testTaskComparision();
     void testChangeReplaySchedule();
     void testCustomTask();
+    void testCompression();
+    void testSyncCompletion();
+    void testPriorities();
 
   private:
     int mCustomCallCount;
