@@ -160,7 +160,7 @@ void ResourceLDAPKIO::entries( KIO::Job *, const KIO::UDSEntryList &list )
   KIO::UDSEntryList::ConstIterator it = list.begin();
   KIO::UDSEntryList::ConstIterator end = list.end();
   for ( ; it != end; ++it ) {
-    const QString urlStr = (*it).stringValue( KIO::UDSEntry::UDS_URL );
+    const QString urlStr = ( *it ).stringValue( KIO::UDSEntry::UDS_URL );
     if ( !urlStr.isEmpty() ) {
       KUrl tmpurl( urlStr );
       d->mResultDn = tmpurl.path();
@@ -589,8 +589,8 @@ KIO::TransferJob *ResourceLDAPKIO::Private::loadFromCache()
 {
   KIO::TransferJob *job = 0;
   if ( mCachePolicy == Cache_Always ||
-     ( mCachePolicy == Cache_NoConnection &&
-      mError == KIO::ERR_COULD_NOT_CONNECT ) ) {
+       ( mCachePolicy == Cache_NoConnection &&
+         mError == KIO::ERR_COULD_NOT_CONNECT ) ) {
 
     mAddr = Addressee();
     mAd = Address( Address::Home );
@@ -753,11 +753,9 @@ void ResourceLDAPKIO::data( KIO::Job *job, const QByteArray &data )
         } else if ( name == d->mAttributes[ QLatin1String( "uid" ) ].toLower() ) {
           d->mAddr.setUid( QString::fromUtf8( value, value.size() ) );
         } else if ( name == d->mAttributes[ QLatin1String( "jpegPhoto" ) ].toLower() ) {
-          KABC::Picture photo;
-          QImage img = QImage::fromData( value );
-          if ( !img.isNull() ) {
-            photo.setData( img );
-            photo.setType( QLatin1String( "image/jpeg" ) );
+          if ( !value.isEmpty() ) {
+            KABC::Picture photo;
+            photo.setRawData( value, QLatin1String( "jpeg" ) );
             d->mAddr.setPhoto( photo );
           }
         }
@@ -882,7 +880,7 @@ void ResourceLDAPKIO::saveResult( KJob *job )
 void ResourceLDAPKIO::saveData( KIO::Job *job, QByteArray &data )
 {
   Q_UNUSED( job );
-  while ( d->mSaveIt != end() && !(*d->mSaveIt).changed() ) {
+  while ( d->mSaveIt != end() && !( *d->mSaveIt ).changed() ) {
     d->mSaveIt++;
   }
 
@@ -892,12 +890,12 @@ void ResourceLDAPKIO::saveData( KIO::Job *job, QByteArray &data )
     return;
   }
 
-  kDebug() << "ResourceLDAPKIO saveData:" << (*d->mSaveIt).assembledName();
+  kDebug() << "ResourceLDAPKIO saveData:" << ( *d->mSaveIt ).assembledName();
 
-  d->AddresseeToLDIF( data, *d->mSaveIt, d->findUid( (*d->mSaveIt).uid() ) );
+  d->AddresseeToLDIF( data, *d->mSaveIt, d->findUid( ( *d->mSaveIt ).uid() ) );
 //  kDebug() << "ResourceLDAPKIO save LDIF:" << QString::fromUtf8(data);
   // mark as unchanged
-  (*d->mSaveIt).setChanged( false );
+  ( *d->mSaveIt ).setChanged( false );
 
   d->mSaveIt++;
 }
@@ -1141,4 +1139,3 @@ QString ResourceLDAPKIO::cacheDst() const
   return d->mCacheDst;
 }
 
-#include "resourceldapkio.moc"
