@@ -22,9 +22,13 @@
 #include "textedit.h"
 #include "inserttabledialog.h"
 #include "tableformatdialog.h"
+
 #include <KActionCollection>
 #include <KLocale>
+
 #include <QTextTable>
+#include <QPointer>
+#include <QDebug>
 
 namespace KPIMTextEdit {
 
@@ -83,7 +87,7 @@ void TableActionMenuPrivate::_k_slotRemoveRowBelow()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.row()<table->rows() - 1 ) {
         table->removeRows( cell.row(), 1 );
       }
@@ -96,7 +100,7 @@ void TableActionMenuPrivate::_k_slotRemoveRowAbove()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.row() >= 1 ) {
         table->removeRows( cell.row() - 1, 1 );
       }
@@ -109,7 +113,7 @@ void TableActionMenuPrivate::_k_slotRemoveColumnBefore()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.column() > 0 ) {
         table->removeColumns( cell.column() - 1, 1 );
       }
@@ -122,7 +126,7 @@ void TableActionMenuPrivate::_k_slotRemoveColumnAfter()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.column()<table->columns() - 1 ) {
         table->removeColumns( cell.column(), 1 );
       }
@@ -135,7 +139,7 @@ void TableActionMenuPrivate::_k_slotInsertRowBelow()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.row()<table->rows() ) {
         table->insertRows( cell.row() + 1, 1 );
       } else {
@@ -150,7 +154,7 @@ void TableActionMenuPrivate::_k_slotInsertRowAbove()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       table->insertRows( cell.row(), 1 );
     }
   }
@@ -161,7 +165,7 @@ void TableActionMenuPrivate::_k_slotInsertColumnBefore()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       table->insertColumns( cell.column(), 1 );
     }
   }
@@ -172,7 +176,7 @@ void TableActionMenuPrivate::_k_slotInsertColumnAfter()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.column()<table->columns() ) {
         table->insertColumns( cell.column() + 1, 1 );
       } else {
@@ -186,7 +190,7 @@ void TableActionMenuPrivate::_k_slotInsertColumnAfter()
 void TableActionMenuPrivate::_k_slotInsertTable()
 {
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
-    InsertTableDialog *dialog = new InsertTableDialog( textEdit );
+    QPointer<InsertTableDialog> dialog = new InsertTableDialog( textEdit );
     if ( dialog->exec() ) {
       QTextCursor cursor = textEdit->textCursor();
       QTextTableFormat tableFormat;
@@ -201,8 +205,9 @@ void TableActionMenuPrivate::_k_slotInsertTable()
           contrains.append( textlength );
       }
       tableFormat.setColumnWidthConstraints( contrains );
-      cursor.insertTable( dialog->rows(), numberOfColumns, tableFormat );
-      textEdit->enableRichTextMode();
+      tableFormat.setAlignment(Qt::AlignLeft);
+      QTextTable *table = cursor.insertTable( dialog->rows(), numberOfColumns);
+      table->setFormat(tableFormat);
     }
     delete dialog;
   }
@@ -213,8 +218,8 @@ void TableActionMenuPrivate::_k_slotMergeCell()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
-      table->mergeCells( cell.row(), cell.column(), 1, 2 );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      table->mergeCells( cell.row(), cell.column(), 1, cell.columnSpan() +1 );
     }
   }
 }
@@ -224,7 +229,7 @@ void TableActionMenuPrivate::_k_slotTableFormat()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      TableFormatDialog *dialog = new TableFormatDialog( textEdit );
+      QPointer<TableFormatDialog> dialog = new TableFormatDialog( textEdit );
       const int numberOfColumn( table->columns() );
       const int numberOfRow( table->rows() );
       dialog->setColumns( numberOfColumn );
@@ -233,6 +238,14 @@ void TableActionMenuPrivate::_k_slotTableFormat()
       dialog->setBorder( tableFormat.border() );
       dialog->setSpacing( tableFormat.cellSpacing() );
       dialog->setPadding( tableFormat.cellPadding() );
+      dialog->setAlignment(tableFormat.alignment());
+
+      QVector<QTextLength> contrains = tableFormat.columnWidthConstraints();
+      if(!contrains.isEmpty()) {
+        dialog->setTypeOfLength(contrains.at(0).type());
+        dialog->setLength(contrains.at(0).rawValue()*numberOfColumn);
+      }
+
       if ( dialog->exec() ) {
         const int newNumberOfColumns(dialog->columns());
         if ( ( newNumberOfColumns != numberOfColumn ) || ( dialog->rows() != numberOfRow ) ) {
@@ -265,9 +278,9 @@ void TableActionMenuPrivate::_k_slotSplitCell()
   if ( textEdit->textMode() == KRichTextEdit::Rich ) {
     QTextTable *table = textEdit->textCursor().currentTable();
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.columnSpan() > 1 ) {
-        table->splitCell( cell.row(), cell.column(), 1, 1 );
+        table->splitCell( cell.row(), cell.column(), 1, cell.columnSpan()-1 );
       }
     }
   }
@@ -291,7 +304,7 @@ void TableActionMenuPrivate::_k_updateActions(bool forceUpdate)
     actionRemoveColumnAfter->setEnabled( isTable );
 
     if ( table ) {
-      QTextTableCell cell = table->cellAt( textEdit->textCursor() );
+      const QTextTableCell cell = table->cellAt( textEdit->textCursor() );
       if ( cell.column()>table->columns() - 2 ) {
         actionMergeCell->setEnabled( false );
       } else {
@@ -368,6 +381,7 @@ TableActionMenu::TableActionMenu(KActionCollection *ac, TextEdit *textEdit)
     removeMenu->addAction( d->actionRemoveColumnAfter );
     ac->addAction( QLatin1String( "remove_column_after" ), d->actionRemoveColumnAfter );
     connect( d->actionRemoveColumnAfter, SIGNAL(triggered(bool)), SLOT(_k_slotRemoveColumnAfter()) );
+    addSeparator();
 
     d->actionMergeCell = new KAction( i18n( "Join With Cell to the Right" ), this );
     ac->addAction( QLatin1String( "join_cell_to_the_right" ), d->actionMergeCell );
